# Changelog

## [Unreleased](https://github.com/sansyrox/robyn/tree/HEAD)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.5...HEAD)

**Merged pull requests:**

- fix: Fixes the crashing dev mode [\#218](https://github.com/sansyrox/robyn/pull/218) ([sansyrox](https://github.com/sansyrox))
- feat: add commitizen as a dev dependency [\#216](https://github.com/sansyrox/robyn/pull/216) ([sansyrox](https://github.com/sansyrox))
- Isort imports [\#205](https://github.com/sansyrox/robyn/pull/205) ([sansyrox](https://github.com/sansyrox))
- Add bridged logger. Improves performance substantially. [\#201](https://github.com/sansyrox/robyn/pull/201) ([sansyrox](https://github.com/sansyrox))
- Adds pre-commit hooks for black, flake8, isort [\#198](https://github.com/sansyrox/robyn/pull/198) ([chrismoradi](https://github.com/chrismoradi))
- Resolves port open issue when app is killed \#183 [\#196](https://github.com/sansyrox/robyn/pull/196) ([anandtripathi5](https://github.com/anandtripathi5))
- Removing unwraps [\#195](https://github.com/sansyrox/robyn/pull/195) ([sansyrox](https://github.com/sansyrox))

## [v0.16.5](https://github.com/sansyrox/robyn/tree/v0.16.5) (2022-06-29)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.4...v0.16.5)

**Closed issues:**

- \[Feature Request\] Add sponsors in the repo and website [\#212](https://github.com/sansyrox/robyn/issues/212)
- \[Feature Request\] Add commitizen as a dev dependency [\#211](https://github.com/sansyrox/robyn/issues/211)
- Add better logging [\#158](https://github.com/sansyrox/robyn/issues/158)
- Remove freeport dependency [\#151](https://github.com/sansyrox/robyn/issues/151)
- Add websocket support [\#104](https://github.com/sansyrox/robyn/issues/104)
- Maintenance issue [\#56](https://github.com/sansyrox/robyn/issues/56)
- Improve Readme [\#4](https://github.com/sansyrox/robyn/issues/4)

## [v0.16.4](https://github.com/sansyrox/robyn/tree/v0.16.4) (2022-05-30)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.3...v0.16.4)

**Closed issues:**

- \[Feature Request\] Remove extra logs [\#200](https://github.com/sansyrox/robyn/issues/200)
- \[Feature Request\] Add precommit hook for black, flake8 and isort [\#194](https://github.com/sansyrox/robyn/issues/194)
- \[BUG\] Get rid of Hashmap Clones and Unwraps! [\#186](https://github.com/sansyrox/robyn/issues/186)

## [v0.16.3](https://github.com/sansyrox/robyn/tree/v0.16.3) (2022-05-18)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.2...v0.16.3)

**Closed issues:**

- \[BUG\] Port not being free on app kill [\#183](https://github.com/sansyrox/robyn/issues/183)
- Build failure [\#166](https://github.com/sansyrox/robyn/issues/166)

## [v0.16.2](https://github.com/sansyrox/robyn/tree/v0.16.2) (2022-05-09)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.1...v0.16.2)

## [v0.16.1](https://github.com/sansyrox/robyn/tree/v0.16.1) (2022-05-09)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.16.0...v0.16.1)

**Closed issues:**

- Add Python stubs [\#130](https://github.com/sansyrox/robyn/issues/130)

**Merged pull requests:**

- Setup types for Robyn [\#192](https://github.com/sansyrox/robyn/pull/192) ([sansyrox](https://github.com/sansyrox))
- Fix build pipeline [\#190](https://github.com/sansyrox/robyn/pull/190) ([sansyrox](https://github.com/sansyrox))
- fix typo :pencil2: in api docs. [\#189](https://github.com/sansyrox/robyn/pull/189) ([sombralibre](https://github.com/sombralibre))
- Remove hashmap clones [\#187](https://github.com/sansyrox/robyn/pull/187) ([sansyrox](https://github.com/sansyrox))
- Code clean up | Modularise rust code [\#185](https://github.com/sansyrox/robyn/pull/185) ([sansyrox](https://github.com/sansyrox))
- Add experimental io-uring [\#184](https://github.com/sansyrox/robyn/pull/184) ([sansyrox](https://github.com/sansyrox))
- Implement Response headers [\#179](https://github.com/sansyrox/robyn/pull/179) ([sansyrox](https://github.com/sansyrox))
- Code cleanup [\#178](https://github.com/sansyrox/robyn/pull/178) ([sansyrox](https://github.com/sansyrox))

## [v0.16.0](https://github.com/sansyrox/robyn/tree/v0.16.0) (2022-04-29)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.15.1...v0.16.0)

**Closed issues:**

- \[Feature Request\] Add list of sponsors on the project website  [\#182](https://github.com/sansyrox/robyn/issues/182)
- Optional build feature for io\_uring [\#177](https://github.com/sansyrox/robyn/issues/177)
- Create Custom headers for the response. [\#174](https://github.com/sansyrox/robyn/issues/174)

## [v0.15.1](https://github.com/sansyrox/robyn/tree/v0.15.1) (2022-03-24)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.15.0...v0.15.1)

**Closed issues:**

- Add middleware support [\#95](https://github.com/sansyrox/robyn/issues/95)

**Merged pull requests:**

- Make websocket id accessible [\#173](https://github.com/sansyrox/robyn/pull/173) ([sansyrox](https://github.com/sansyrox))
- Use Clippy tool optimized code [\#171](https://github.com/sansyrox/robyn/pull/171) ([mrxiaozhuox](https://github.com/mrxiaozhuox))
- Modify headers [\#170](https://github.com/sansyrox/robyn/pull/170) ([sansyrox](https://github.com/sansyrox))
- Update README.md [\#168](https://github.com/sansyrox/robyn/pull/168) ([Polokghosh53](https://github.com/Polokghosh53))

## [v0.15.0](https://github.com/sansyrox/robyn/tree/v0.15.0) (2022-03-17)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.14.0...v0.15.0)

**Closed issues:**

- \[BUG\] Unable to modify headers in middlewares [\#167](https://github.com/sansyrox/robyn/issues/167)
- Add Pycon talk link to docs [\#102](https://github.com/sansyrox/robyn/issues/102)

## [v0.14.0](https://github.com/sansyrox/robyn/tree/v0.14.0) (2022-03-03)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.13.1...v0.14.0)

**Fixed bugs:**

- Build error [\#161](https://github.com/sansyrox/robyn/issues/161)

**Merged pull requests:**

- Implement Custom Response objects. [\#165](https://github.com/sansyrox/robyn/pull/165) ([sansyrox](https://github.com/sansyrox))
- Remove deprecated endpoints [\#162](https://github.com/sansyrox/robyn/pull/162) ([sansyrox](https://github.com/sansyrox))
- Fix: default url param in app.start [\#160](https://github.com/sansyrox/robyn/pull/160) ([sansyrox](https://github.com/sansyrox))
- Add middlewares [\#157](https://github.com/sansyrox/robyn/pull/157) ([sansyrox](https://github.com/sansyrox))
- Remove arc\(ing\) [\#156](https://github.com/sansyrox/robyn/pull/156) ([sansyrox](https://github.com/sansyrox))

## [v0.13.1](https://github.com/sansyrox/robyn/tree/v0.13.1) (2022-02-19)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.13.0...v0.13.1)

## [v0.13.0](https://github.com/sansyrox/robyn/tree/v0.13.0) (2022-02-15)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.12.1...v0.13.0)

## [v0.12.1](https://github.com/sansyrox/robyn/tree/v0.12.1) (2022-02-13)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.12.0...v0.12.1)

**Closed issues:**

- \[BUG\] Default URL cannot be assigned [\#159](https://github.com/sansyrox/robyn/issues/159)
- Upcoming release\(s\) [\#141](https://github.com/sansyrox/robyn/issues/141)

## [v0.12.0](https://github.com/sansyrox/robyn/tree/v0.12.0) (2022-01-21)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.11.1...v0.12.0)

**Closed issues:**

- Consider adding startup events [\#153](https://github.com/sansyrox/robyn/issues/153)
- Remove poetry dependency [\#150](https://github.com/sansyrox/robyn/issues/150)

**Merged pull requests:**

- Add Event handlers [\#154](https://github.com/sansyrox/robyn/pull/154) ([sansyrox](https://github.com/sansyrox))
- Remove poetry [\#152](https://github.com/sansyrox/robyn/pull/152) ([sansyrox](https://github.com/sansyrox))
- Use print instead of input after starting server [\#149](https://github.com/sansyrox/robyn/pull/149) ([klaa97](https://github.com/klaa97))
- Fix dev server [\#148](https://github.com/sansyrox/robyn/pull/148) ([sansyrox](https://github.com/sansyrox))
- URL queries [\#146](https://github.com/sansyrox/robyn/pull/146) ([patchgamestudio](https://github.com/patchgamestudio))
- Add project wide flake8 settings [\#143](https://github.com/sansyrox/robyn/pull/143) ([sansyrox](https://github.com/sansyrox))

## [v0.11.1](https://github.com/sansyrox/robyn/tree/v0.11.1) (2022-01-11)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.11.0...v0.11.1)

## [v0.11.0](https://github.com/sansyrox/robyn/tree/v0.11.0) (2022-01-07)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.10.0...v0.11.0)

**Fixed bugs:**

- Hot Reloading goes in an infinite loop [\#115](https://github.com/sansyrox/robyn/issues/115)

**Closed issues:**

- Benchmarks to Björn, uvicorn etc.  [\#142](https://github.com/sansyrox/robyn/issues/142)
- Add Python linter setup [\#129](https://github.com/sansyrox/robyn/issues/129)
- Add fixtures in testing [\#84](https://github.com/sansyrox/robyn/issues/84)

## [v0.10.0](https://github.com/sansyrox/robyn/tree/v0.10.0) (2021-12-20)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.9.0...v0.10.0)

**Closed issues:**

- Add PyPI classifiers [\#127](https://github.com/sansyrox/robyn/issues/127)
- Robyn version 0.9.0 doesn't work on Mac M1 Models  [\#120](https://github.com/sansyrox/robyn/issues/120)
- Inconsistency in steps mentioned in Readme to run locally  [\#119](https://github.com/sansyrox/robyn/issues/119)
- Async web socket support [\#116](https://github.com/sansyrox/robyn/issues/116)
- Reveal Logo to be removed from Future Roadmap [\#107](https://github.com/sansyrox/robyn/issues/107)
- Dead Link for Test Drive Button on Robyn Landing Page  [\#106](https://github.com/sansyrox/robyn/issues/106)
- Add issue template, pr template and community guidelines [\#105](https://github.com/sansyrox/robyn/issues/105)
- For v0.7.0 [\#72](https://github.com/sansyrox/robyn/issues/72)
- Add better support for requests and response! [\#13](https://github.com/sansyrox/robyn/issues/13)

**Merged pull requests:**

- Add async support in WS [\#134](https://github.com/sansyrox/robyn/pull/134) ([sansyrox](https://github.com/sansyrox))
- Add help messages and simplify 'dev' option [\#128](https://github.com/sansyrox/robyn/pull/128) ([Kludex](https://github.com/Kludex))
- Apply Python highlight on api.md [\#126](https://github.com/sansyrox/robyn/pull/126) ([Kludex](https://github.com/Kludex))
- Update comparison.md [\#124](https://github.com/sansyrox/robyn/pull/124) ([Kludex](https://github.com/Kludex))
- Update comparison.md [\#123](https://github.com/sansyrox/robyn/pull/123) ([Kludex](https://github.com/Kludex))
- Fix readme documentation [\#122](https://github.com/sansyrox/robyn/pull/122) ([sansyrox](https://github.com/sansyrox))
- Release v0.9.0 Changelog [\#121](https://github.com/sansyrox/robyn/pull/121) ([sansyrox](https://github.com/sansyrox))
- \[FEAT\] Open Source Contribution Templates [\#118](https://github.com/sansyrox/robyn/pull/118) ([shivaylamba](https://github.com/shivaylamba))
- FIX : Wrong link for Test Drive [\#117](https://github.com/sansyrox/robyn/pull/117) ([shivaylamba](https://github.com/shivaylamba))

## [v0.9.0](https://github.com/sansyrox/robyn/tree/v0.9.0) (2021-12-01)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.8.1...v0.9.0)

**Closed issues:**

- Add more HTTP methods [\#74](https://github.com/sansyrox/robyn/issues/74)

**Merged pull requests:**

- Fix default url bug [\#111](https://github.com/sansyrox/robyn/pull/111) ([sansyrox](https://github.com/sansyrox))
- Web socket integration attempt 2 [\#109](https://github.com/sansyrox/robyn/pull/109) ([sansyrox](https://github.com/sansyrox))

## [v0.8.1](https://github.com/sansyrox/robyn/tree/v0.8.1) (2021-11-17)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.8.0...v0.8.1)

**Fixed bugs:**

- The default start is running the server at '0.0.0.0' instead of '127.0.0.1' [\#110](https://github.com/sansyrox/robyn/issues/110)

## [v0.8.0](https://github.com/sansyrox/robyn/tree/v0.8.0) (2021-11-10)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.7.1...v0.8.0)

**Closed issues:**

- Share the TCP web socket across different cores [\#91](https://github.com/sansyrox/robyn/issues/91)
- Improve the router [\#52](https://github.com/sansyrox/robyn/issues/52)
- \[Stretch Goal\] Create a a way of writing async request [\#32](https://github.com/sansyrox/robyn/issues/32)
- Improve the router [\#29](https://github.com/sansyrox/robyn/issues/29)

**Merged pull requests:**

- Fix the failing testing suite! [\#100](https://github.com/sansyrox/robyn/pull/100) ([sansyrox](https://github.com/sansyrox))
- Requests object is now optional [\#99](https://github.com/sansyrox/robyn/pull/99) ([sansyrox](https://github.com/sansyrox))
- Add socket sharing [\#94](https://github.com/sansyrox/robyn/pull/94) ([sansyrox](https://github.com/sansyrox))

## [v0.7.1](https://github.com/sansyrox/robyn/tree/v0.7.1) (2021-10-28)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.7.0...v0.7.1)

**Closed issues:**

- Remove the solution using dockerisation of tests [\#98](https://github.com/sansyrox/robyn/issues/98)
- Functions not working without request param [\#96](https://github.com/sansyrox/robyn/issues/96)
- Add actix router [\#85](https://github.com/sansyrox/robyn/issues/85)
- Request apart from GET are not working in directory subroutes [\#79](https://github.com/sansyrox/robyn/issues/79)
- Add the ability to share the server across the network [\#69](https://github.com/sansyrox/robyn/issues/69)
- Add the ability to view headers in the HTTP Methods [\#54](https://github.com/sansyrox/robyn/issues/54)
- Add tests! [\#8](https://github.com/sansyrox/robyn/issues/8)

## [v0.7.0](https://github.com/sansyrox/robyn/tree/v0.7.0) (2021-10-03)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.6.1...v0.7.0)

**Closed issues:**

- Robyn the replacement of Quart [\#86](https://github.com/sansyrox/robyn/issues/86)
- Add Pytest support for the test endpoints [\#81](https://github.com/sansyrox/robyn/issues/81)

**Merged pull requests:**

- Finally completed router integration [\#90](https://github.com/sansyrox/robyn/pull/90) ([sansyrox](https://github.com/sansyrox))
- Address clippy lints [\#89](https://github.com/sansyrox/robyn/pull/89) ([SanchithHegde](https://github.com/SanchithHegde))
- Initial docs update [\#83](https://github.com/sansyrox/robyn/pull/83) ([sansyrox](https://github.com/sansyrox))
- Add the basics of python testing [\#82](https://github.com/sansyrox/robyn/pull/82) ([sansyrox](https://github.com/sansyrox))
- Add a new landing page [\#80](https://github.com/sansyrox/robyn/pull/80) ([sansyrox](https://github.com/sansyrox))

## [v0.6.1](https://github.com/sansyrox/robyn/tree/v0.6.1) (2021-08-30)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.6.0...v0.6.1)

**Closed issues:**

- Make a new release [\#71](https://github.com/sansyrox/robyn/issues/71)
- Update to the pyo3 v0.14 [\#63](https://github.com/sansyrox/robyn/issues/63)
- Add the support to serve static directories [\#55](https://github.com/sansyrox/robyn/issues/55)
- Add support for mounting directory [\#38](https://github.com/sansyrox/robyn/issues/38)

**Merged pull requests:**

- Add the base of http requests [\#78](https://github.com/sansyrox/robyn/pull/78) ([sansyrox](https://github.com/sansyrox))
- Add default port and a variable url [\#77](https://github.com/sansyrox/robyn/pull/77) ([sansyrox](https://github.com/sansyrox))
- Make the request object accessible in every route [\#76](https://github.com/sansyrox/robyn/pull/76) ([sansyrox](https://github.com/sansyrox))
- Add the basics for circle ci and testing framework [\#67](https://github.com/sansyrox/robyn/pull/67) ([sansyrox](https://github.com/sansyrox))
- Update to pyo3 v0.14 [\#65](https://github.com/sansyrox/robyn/pull/65) ([sansyrox](https://github.com/sansyrox))
- Add the static directory serving [\#64](https://github.com/sansyrox/robyn/pull/64) ([sansyrox](https://github.com/sansyrox))
- Create a request object [\#61](https://github.com/sansyrox/robyn/pull/61) ([sansyrox](https://github.com/sansyrox))
- Add the ability to add body in PUT, PATCH and DELETE [\#60](https://github.com/sansyrox/robyn/pull/60) ([sansyrox](https://github.com/sansyrox))
- Implement a working dev server [\#40](https://github.com/sansyrox/robyn/pull/40) ([sansyrox](https://github.com/sansyrox))
- Use Actix as base [\#35](https://github.com/sansyrox/robyn/pull/35) ([JackThomson2](https://github.com/JackThomson2))

## [v0.6.0](https://github.com/sansyrox/robyn/tree/v0.6.0) (2021-08-11)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.3...v0.6.0)

**Closed issues:**

- Add body support for PUT, POST and PATCH [\#53](https://github.com/sansyrox/robyn/issues/53)
- Away with limited internet access till 1st August [\#51](https://github.com/sansyrox/robyn/issues/51)
- Add doc stings [\#42](https://github.com/sansyrox/robyn/issues/42)
- OSX builds are failing [\#41](https://github.com/sansyrox/robyn/issues/41)
- Add a dev server implementation [\#37](https://github.com/sansyrox/robyn/issues/37)
- Mini Roadmap | A list of issues that would require fixing [\#19](https://github.com/sansyrox/robyn/issues/19)
- Add support for Object/JSON Return Type! [\#9](https://github.com/sansyrox/robyn/issues/9)

## [v0.5.3](https://github.com/sansyrox/robyn/tree/v0.5.3) (2021-07-12)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.2...v0.5.3)

**Merged pull requests:**

- Improve the HTML file serving [\#46](https://github.com/sansyrox/robyn/pull/46) ([sansyrox](https://github.com/sansyrox))
- Add the basics to add serving of static files [\#36](https://github.com/sansyrox/robyn/pull/36) ([sansyrox](https://github.com/sansyrox))

## [v0.5.2](https://github.com/sansyrox/robyn/tree/v0.5.2) (2021-07-11)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.1...v0.5.2)

## [v0.5.1](https://github.com/sansyrox/robyn/tree/v0.5.1) (2021-07-10)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.0...v0.5.1)

**Closed issues:**

- Make html file serving more robust [\#45](https://github.com/sansyrox/robyn/issues/45)
- Try to serve individual static files using vanilla rust [\#43](https://github.com/sansyrox/robyn/issues/43)
- Error on import  [\#16](https://github.com/sansyrox/robyn/issues/16)
- Add multiple process sharing [\#2](https://github.com/sansyrox/robyn/issues/2)

## [v0.5.0](https://github.com/sansyrox/robyn/tree/v0.5.0) (2021-07-01)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.4.1...v0.5.0)

**Closed issues:**

- QPS drops drastically after processing many requests [\#31](https://github.com/sansyrox/robyn/issues/31)
- Improve the way you parse TCP streams [\#30](https://github.com/sansyrox/robyn/issues/30)
- Re-introduce thread pool for the sync functions \(maybe\) [\#22](https://github.com/sansyrox/robyn/issues/22)
- Add async listener object in rust stream! [\#11](https://github.com/sansyrox/robyn/issues/11)

**Merged pull requests:**

- Make the server http compliant [\#33](https://github.com/sansyrox/robyn/pull/33) ([sansyrox](https://github.com/sansyrox))

## [v0.4.1](https://github.com/sansyrox/robyn/tree/v0.4.1) (2021-06-26)

[Full Changelog](https://github.com/sansyrox/robyn/compare/0.4.0...v0.4.1)

**Closed issues:**

- Add PyPi Metadata [\#5](https://github.com/sansyrox/robyn/issues/5)

**Merged pull requests:**

- Build and publish wheels on GitHub Actions [\#26](https://github.com/sansyrox/robyn/pull/26) ([messense](https://github.com/messense))
- Code cleanup using PyFunction type [\#25](https://github.com/sansyrox/robyn/pull/25) ([sansyrox](https://github.com/sansyrox))
- Add non blocking sync functions [\#23](https://github.com/sansyrox/robyn/pull/23) ([sansyrox](https://github.com/sansyrox))
- Add support for sync functions [\#20](https://github.com/sansyrox/robyn/pull/20) ([sansyrox](https://github.com/sansyrox))

## [0.4.0](https://github.com/sansyrox/robyn/tree/0.4.0) (2021-06-22)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.3.0...0.4.0)

**Closed issues:**

- Add support for Sync functions as well! [\#7](https://github.com/sansyrox/robyn/issues/7)

## [v0.3.0](https://github.com/sansyrox/robyn/tree/v0.3.0) (2021-06-21)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.2.3...v0.3.0)

**Closed issues:**

- Architecture link in readme redirects to raw content [\#18](https://github.com/sansyrox/robyn/issues/18)
- Link pointing to the wrong destination [\#6](https://github.com/sansyrox/robyn/issues/6)

**Merged pull requests:**

- Pure tokio [\#17](https://github.com/sansyrox/robyn/pull/17) ([JackThomson2](https://github.com/JackThomson2))
- Remove Mutex lock on Threadpool and routes [\#15](https://github.com/sansyrox/robyn/pull/15) ([JackThomson2](https://github.com/JackThomson2))

## [v0.2.3](https://github.com/sansyrox/robyn/tree/v0.2.3) (2021-06-18)

[Full Changelog](https://github.com/sansyrox/robyn/compare/c14f52e6faa79917e89de4220590da7bf28f6a65...v0.2.3)

**Closed issues:**

- Improve async runtime [\#3](https://github.com/sansyrox/robyn/issues/3)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
